read_kernel_page_table

Function read_kernel_page_table 

pub fn read_kernel_page_table() -> PhysAddr
Reads the current page table root register for kernel space (TTBR1_EL1).

When the “arm-el2” feature is enabled, TTBR0_EL2 is dedicated to the Hypervisor’s Stage-2 page table base address.

Returns the physical address of the page table root.