pub enum DataCacheOperation {
Clean,
Invalidate,
CleanInvalidate,
}Expand description
Data-cache maintenance performed to the point of coherency.
Variants
Clean
Writes dirty data back while retaining valid cache lines.
Invalidate
Discards cached contents without writing them back.
CleanInvalidate
Writes dirty contents back and discards the cache lines.