sync_kernel_text

Function sync_kernel_text 

pub fn sync_kernel_text(start: VirtAddr, size: usize)
Completes local translation and instruction synchronization for modified text. The owner must first publish the modified bytes using clean_dcache_range_to_pou, and coordinate any other CPUs executing this text.