Module capability

Module capability 

CPU hardware identity.

Structs

CpuIdx86-64
The main type used to query information about the CPU we’re running on.
CpuidResultx86-64
Result of the cpuid instruction.

Enums

Hypervisorx86-64
Identifies the different Hypervisor products.

Functions

cpuidx86-64
Reads one CPUID leaf and subleaf from the current CPU. The caller interprets only leaves advertised by the corresponding maximum basic or extended leaf and keeps CPU affinity when combining observations.
physical_address_bitsx86-64
Returns the implemented physical-address width, or None without leaf 80000008.