pub enum InstalledAddressSpaceMode {
Tagged,
FullFlush,
}Expand description
Hardware tag policy carried with an installed userspace address space.
Variants
Tagged
The architecture may retain translations distinguished by a hardware tag and software generation.
FullFlush
The architecture uses tag zero and flushes translations when changing address spaces.