pub enum UserAccessType {
Read,
Write,
}Available on crate feature
uspace only.Expand description
Direction of an architecture-level user-memory access check.
Variants
Read
The kernel intends to read bytes supplied by user space.
Write
The kernel intends to write bytes into user space.