pub enum PmuError {
Unavailable,
InvalidCounter,
UnsupportedEvent,
InvalidConfiguration,
InvalidPeriod,
}Available on AArch64 and crate feature
pmu only.Expand description
A requested PMU operation could not be performed.
Variants
This CPU does not implement architectural PMUv3.
InvalidCounter
The counter index is not implemented on this CPU.
UnsupportedEvent
The event is architecturally reported as unsupported.
InvalidConfiguration
The configuration does not apply to the selected counter.
InvalidPeriod
The requested period is zero or exceeds the active counter width.