pub fn set_breakpoint_handler(handler: BreakpointHandler) -> BreakpointHandlerExpand description
Installs the global breakpoint trap hook and returns the previous one.
pub fn set_breakpoint_handler(handler: BreakpointHandler) -> BreakpointHandlerInstalls the global breakpoint trap hook and returns the previous one.