pub fn set_debug_handler(handler: DebugHandler) -> DebugHandlerExpand description
Installs the global debug trap hook and returns the previous one.
pub fn set_debug_handler(handler: DebugHandler) -> DebugHandlerInstalls the global debug trap hook and returns the previous one.