Module user

Module user 

Available on crate feature uspace only.
User execution and nofault memory access.

Modules

ESR_EL1

Structs

ExceptionInfo
Information about an exception that occurred in user space.
ExceptionSyndrome
Architecture-neutral syndrome fields for user-space exceptions.
Field
Specific section of a register.
FieldValue
Values for the specific register fields.
LocalRegisterCopy
A read-write copy of register contents.
RegisterDebugValue
RegisterDebugValue captures a register’s value and implements fmt::Debug to provide a human-readable representation of the register state.
UserContext
Context to enter user space.

Enums

ExceptionKind
A generalized kind for ExceptionInfo.
ReturnReason
A reason as to why the control of the CPU is returned from the user space to the kernel.
UserAccessError
Failure returned by a nofault user read.
UserAccessType
Direction of an architecture-level user-memory access check.
UserAtomicError
Failure returned by a nofault user atomic operation.
UserAtomicU32Op
Atomic operation supported by user_atomic_u32.

Constants

ESR_EL1

Traits

NoUninit
Marker trait for “plain old data” types with no uninit (or padding) bytes.
Readable
Readable register
RegisterDebugInfo
RegisterDebugInfo exposes debugging information from register types.
RegisterLongName
Descriptive name for each register.
TryFromValue
Conversion of raw register value into enumerated values member. Implemented inside register_bitfields! macro for each bit field.
UIntLike
Trait representing the base type of registers.

Functions

user_access_ok_page
Probes whether EL0 is permitted to access the page containing vaddr under the current user translation regime (TTBR0_EL1), without taking any lock.
user_atomic_u32
Atomically updates one aligned user-space word without resolving faults.
user_cmpxchg_u32
Compares and conditionally replaces one aligned user word without faulting in pages.
user_copy
Copies data from source to destination, where addresses may be in user space. Equivalent to memcpy.
user_read_u32
Reads one aligned user-space word without resolving faults.