FieldValue

Struct FieldValue 

pub struct FieldValue<T, R>{
    pub value: T,
    /* private fields */
}
Available on crate feature uspace only.
Values for the specific register fields.

For the FieldValue, the masks and values are shifted into their actual location in the register.

Fields

value: T

Implementations

Source

impl<R> FieldValue<u8, R>

pub const fn new(mask: u8, shift: usize, value: u8) -> FieldValue<u8, R>

Source

impl<R> FieldValue<u16, R>

pub const fn new(mask: u16, shift: usize, value: u16) -> FieldValue<u16, R>

Source

impl<R> FieldValue<u32, R>

pub const fn new(mask: u32, shift: usize, value: u32) -> FieldValue<u32, R>

Source

impl<R> FieldValue<u64, R>

pub const fn new(mask: u64, shift: usize, value: u64) -> FieldValue<u64, R>

Source

impl<R> FieldValue<u128, R>

pub const fn new(mask: u128, shift: usize, value: u128) -> FieldValue<u128, R>

Source

impl<R> FieldValue<usize, R>

pub const fn new( mask: usize, shift: usize, value: usize, ) -> FieldValue<usize, R>

Source

impl<T, R> FieldValue<T, R>

pub fn none() -> FieldValue<T, R>

pub const fn mask(&self) -> T

Get the raw bitmask represented by this FieldValue.

pub fn read(&self, field: Field<T, R>) -> T

pub fn modify(self, val: T) -> T

Modify fields in a register value

pub fn any_matching_bits_set(&self, val: T) -> bool

Check if any of the bits covered by the mask for this FieldValue and set in the FieldValue are also set in the passed value

pub fn matches_all(&self, val: T) -> bool

Check if all specified parts of a field match