Available on crate feature
uspace only.Expand description
Structures and functions for user space.
Structs
- Exception
Info - Information about an exception that occurred in user space.
- User
Context - Context to enter user space.
Enums
- Exception
Kind - A generalized kind for
ExceptionInfo. - Return
Reason - A reason as to why the control of the CPU is returned from the user space to the kernel.