pub enum ReturnReason {
Interrupt,
Syscall,
PageFault(VirtAddr, PageFaultFlags),
Exception(ExceptionInfo),
Unknown,
}Available on crate feature
uspace only.Expand description
A reason as to why the control of the CPU is returned from the user space to the kernel.
Variants
Interrupt
An interrupt.
Syscall
A system call.
PageFault(VirtAddr, PageFaultFlags)
A page fault.
Exception(ExceptionInfo)
Other kinds of exceptions.
Unknown
Unknown reason.