Wrapper functions for assembly instructions.
Functions
- address_
space_ tag_ capacity - Returns the number of usable x86 PCID values, including reserved PCID 0.
- disable_
irqs - Makes the current CPU to ignore interrupts.
- enable_
irqs - Allows the current CPU to respond to interrupts.
- flush_
icache_ all - Flushes the entire instruction cache.
- flush_
tlb - Flushes the TLB.
- halt
- Halt the current CPU.
- install_
user_ ⚠address_ space uspace - Installs one complete userspace identity into CR3.
- irqs_
enabled - Returns whether the current CPU is allowed to respond to interrupts.
- read_
kernel_ page_ table - Reads the current page table root register for kernel space (
CR3). - read_
user_ page_ table - Reads the current page table root register for user space (
CR3). - update_
mmu_ cache - Makes a page-table entry installed by the local page-fault handler visible before retrying the faulting instruction.
- user_
access_ ⚠ok_ page uspace - Lock-free EL0/user access probe. No hardware address-translation probe is wired up on this architecture yet, so always report a present-page probe miss and let the caller take the locked slow path (correctness preserved).
- user_
copy ⚠uspace - Copies data from source to destination, where addresses may be in user space. Equivalent to memcpy.
- wait_
for_ irqs - Relaxes the current CPU and waits for interrupts.
- wait_
for_ irqs_ disabled - Waits for an interrupt after the caller masks local IRQ delivery.
- write_
kernel_ ⚠page_ table - Writes the register to update the current page table root for kernel space
(
CR3). - write_
user_ ⚠page_ table - Writes the register to update the current page table root for user space
(
CR3).