pub struct Native;Available on non-AArch64 only.
Native kernel translation regime selected by the target architecture.
Implementations
Sourceimpl Native
impl Native
Sourcepub fn read_kernel_page_table() -> PhysAddr
pub fn read_kernel_page_table() -> PhysAddr
Returns the current kernel page-table root.
Sourcepub unsafe fn write_kernel_page_table(root: PhysAddr)
pub unsafe fn write_kernel_page_table(root: PhysAddr)
Installs a native kernel root without implicit invalidation.
Safety
All current code, stack and data mappings must remain valid, and the owner must retain the tables and arrange required TLB invalidation.
Sourcepub fn flush_tlb(address: Option<VirtAddr>)
pub fn flush_tlb(address: Option<VirtAddr>)
Invalidates a native translation or the entire native local TLB.
Sourcepub fn flush_tlb_range(start: VirtAddr, size: usize)
pub fn flush_tlb_range(start: VirtAddr, size: usize)
Invalidates native translations intersecting a byte range.
Sourcepub fn address_space_tag_capacity() -> u32
pub fn address_space_tag_capacity() -> u32
Returns the current CPU’s native hardware address-space tag capacity.