TaskContext

Struct TaskContext 

#[repr(C)]
pub struct TaskContext {
Show 17 fields pub ra: usize, pub sp: usize, pub s0: usize, pub s1: usize, pub s2: usize, pub s3: usize, pub s4: usize, pub s5: usize, pub s6: usize, pub s7: usize, pub s8: usize, pub s9: usize, pub s10: usize, pub s11: usize, pub tp: usize, pub satp: PhysAddr, pub fp_state: FpState,
}
Saved hardware states of a task.

The context usually includes:

  • Callee-saved registers
  • Stack pointer register
  • Thread pointer register (for kernel-space thread-local storage)
  • FP/SIMD registers

On context switch, current task saves its context from CPU to memory, and the next task restores its context from memory to CPU.

Fields

ra: usizesp: usizes0: usizes1: usizes2: usizes3: usizes4: usizes5: usizes6: usizes7: usizes8: usizes9: usizes10: usizes11: usizetp: usize

Thread Pointer

satp: PhysAddr
Available on crate feature uspace only.

The satp register value, i.e., the page table root.

fp_state: FpState
Available on crate feature fp-simd only.

Implementations

Source

impl TaskContext

pub fn new() -> Self

Creates a dummy context for a new task.

Note the context is not initialized, it will be filled by switch_to (for initial tasks) and init (for regular tasks) methods.

pub fn init(&mut self, entry: usize, kstack_top: VirtAddr, tls_area: VirtAddr)

Initializes the context for a new task, with the given entry point and kernel stack.

pub fn set_page_table_root(&mut self, satp: PhysAddr)

Available on crate feature uspace only.

Changes the page table root in this context.

The hardware register for page table root (satp for riscv64) will be updated to the next task’s after Self::switch_to.

pub fn switch_to(&mut self, next_ctx: &Self)

Switches to another task.

It first saves the current task’s context from CPU to this place, and then restores the next task’s context from next_ctx to CPU.