#[repr(C)]pub struct TaskContext {}Expand description
Saved hardware states of a task.
The context usually includes:
- Callee-saved registers
- Stack pointer register
- Thread pointer register (for kernel-space thread-local storage)
- FP/SIMD registers
On context switch, current task saves its context from CPU to memory, and the next task restores its context from memory to CPU.
Fields
ra: usizesp: usizes0: usizes1: usizes2: usizes3: usizes4: usizes5: usizes6: usizes7: usizes8: usizes9: usizes10: usizes11: usizetp: usizeThread Pointer
satp: PhysAddrAvailable on crate feature
uspace only.The satp register value, i.e., the page table root.
fp_state: FpStateAvailable on crate feature
fp-simd only.Implementations
Sourceimpl TaskContext
impl TaskContext
Sourcepub fn init(&mut self, entry: usize, kstack_top: VirtAddr, tls_area: VirtAddr)
pub fn init(&mut self, entry: usize, kstack_top: VirtAddr, tls_area: VirtAddr)
Initializes the context for a new task, with the given entry point and kernel stack.
Sourcepub fn set_page_table_root(&mut self, satp: PhysAddr)
Available on crate feature uspace only.
pub fn set_page_table_root(&mut self, satp: PhysAddr)
uspace only.Changes the page table root in this context.
The hardware register for page table root (satp for riscv64) will be
updated to the next task’s after Self::switch_to.