Trap handling.
Re-exports
pub use crate::KernelTrapFrame;pub use crate::UserRegisters;
Structs
- Page
Fault Flags - Access information reported by a CPU page-fault trap.
Enums
- Trap
Origin - Privilege domain that owns a saved register image.
Functions
- breakpoint_
handler - Breakpoint handler.
- debug_
handler - Debug handler.
- dispatch_
irq - Dispatches an IRQ through the runtime-registered handler, or the default handler.
- dispatch_
page_ fault - Dispatches a page fault through the runtime-registered handler, or the default handler.
- irq_
handler - Dispatches an IRQ to the installed trap hook.
- page_
fault_ handler - Dispatches a page fault to the installed trap hook.
- set_
breakpoint_ handler - Installs the global breakpoint trap hook and returns the previous one.
- set_
debug_ handler - Installs the global debug trap hook and returns the previous one.
- set_
irq_ handler - Installs the global IRQ trap hook and returns the previous one.
- set_
page_ fault_ handler - Installs the global page-fault trap hook and returns the previous one.
Type Aliases
- Breakpoint
Handler - Breakpoint trap hook type.
- Debug
Handler - Debug trap hook type.
- IrqHandler
- IRQ trap hook type.
- Page
Fault Handler - Page-fault trap hook type.