Module trap

Module trap 

Trap handling.

Re-exports

pub use crate::KernelTrapFrame;
pub use crate::UserRegisters;

Structs

PageFaultFlags
Access information reported by a CPU page-fault trap.

Enums

TrapOrigin
Privilege domain that owns a saved register image.

Functions

breakpoint_handler
Breakpoint handler.
debug_handler
Debug handler.
dispatch_irq
Dispatches an IRQ through the runtime-registered handler, or the default handler.
dispatch_page_fault
Dispatches a page fault through the runtime-registered handler, or the default handler.
irq_handler
Dispatches an IRQ to the installed trap hook.
page_fault_handler
Dispatches a page fault to the installed trap hook.
set_breakpoint_handler
Installs the global breakpoint trap hook and returns the previous one.
set_debug_handler
Installs the global debug trap hook and returns the previous one.
set_irq_handler
Installs the global IRQ trap hook and returns the previous one.
set_page_fault_handler
Installs the global page-fault trap hook and returns the previous one.

Type Aliases

BreakpointHandler
Breakpoint trap hook type.
DebugHandler
Debug trap hook type.
IrqHandler
IRQ trap hook type.
PageFaultHandler
Page-fault trap hook type.