Available on crate feature
uspace only.Expand description
User execution and nofault memory access.
Modules
Structs
- Exception
Info - Information about an exception that occurred in user space.
- Exception
Syndrome - Architecture-neutral syndrome fields for user-space exceptions.
- Field
- Specific section of a register.
- Field
Value - Values for the specific register fields.
- Local
Register Copy - A read-write copy of register contents.
- Register
Debug Value RegisterDebugValuecaptures a register’s value and implementsfmt::Debugto provide a human-readable representation of the register state.- User
Context - Context to enter user space.
Enums
- Exception
Kind - A generalized kind for
ExceptionInfo. - Return
Reason - A reason as to why the control of the CPU is returned from the user space to the kernel.
- User
Access Error - Failure returned by a nofault user read.
- User
Access Type - Direction of an architecture-level user-memory access check.
- User
Atomic Error - Failure returned by a nofault user atomic operation.
- User
Atomic U32Op - Atomic operation supported by
user_atomic_u32.
Constants
Traits
- NoUninit
- Marker trait for “plain old data” types with no uninit (or padding) bytes.
- Readable
- Readable register
- Register
Debug Info RegisterDebugInfoexposes debugging information from register types.- Register
Long Name - Descriptive name for each register.
- TryFrom
Value - Conversion of raw register value into enumerated values member. Implemented inside register_bitfields! macro for each bit field.
- UInt
Like - Trait representing the base type of registers.
Functions
- user_
access_ ⚠ok_ page - Probes whether EL0 is permitted to access the page containing
vaddrunder the current user translation regime (TTBR0_EL1), without taking any lock. - user_
atomic_ ⚠u32 - Atomically updates one aligned user-space word without resolving faults.
- user_
cmpxchg_ ⚠u32 - Compares and conditionally replaces one aligned user word without faulting in pages.
- user_
copy ⚠ - Copies data from source to destination, where addresses may be in user space. Equivalent to memcpy.
- user_
read_ ⚠u32 - Reads one aligned user-space word without resolving faults.