Module user

Module user 

Available on crate feature uspace only.
User execution and nofault memory access.

Structs

ExceptionInfo
Information about an exception that occurred in user space.
ExceptionSyndrome
Architecture-neutral syndrome fields for user-space exceptions.
UserContext
Context to enter user space.

Enums

ExceptionKind
A generalized kind for ExceptionInfo.
ReturnReason
A reason as to why the control of the CPU is returned from the user space to the kernel.
UserAccessError
Failure returned by a nofault user read.
UserAccessType
Direction of an architecture-level user-memory access check.
UserAtomicError
Failure returned by a nofault user atomic operation.
UserAtomicU32Op
Atomic operation supported by user_atomic_u32.

Traits

NoUninit
Marker trait for “plain old data” types with no uninit (or padding) bytes.

Functions

user_access_ok_page
Lock-free EL0/user access probe. No hardware address-translation probe is wired up on this architecture yet, so always report a present-page probe miss and let the caller take the locked slow path (correctness preserved).
user_atomic_u32
Atomically updates one aligned user-space word without resolving faults.
user_cmpxchg_u32
Compares and conditionally replaces one aligned user word without faulting in pages.
user_copy
Copies data from source to destination, where addresses may be in user space. Equivalent to memcpy.
user_read_u32
Reads one aligned user-space word without resolving faults.