Module uspace

Module uspace 

Available on crate feature uspace only.
Structures and functions for user space.

Structs

ExceptionInfo
Information about an exception that occurred in user space.
UserContext
Context to enter user space.

Enums

ExceptionKind
A generalized kind for ExceptionInfo.
ReturnReason
A reason as to why the control of the CPU is returned from the user space to the kernel.