pub struct UserContext {
pub fs_base: u64,
pub gs_base: u64,
/* private fields */
}Available on crate feature
uspace only.Expand description
Context to enter user space.
Fields
fs_base: u64FS Segment Base
gs_base: u64GS Segment Base
Implementations
Sourceimpl UserContext
impl UserContext
Sourcepub fn new(entry: usize, ustack_top: VirtAddr, arg0: usize) -> Self
pub fn new(entry: usize, ustack_top: VirtAddr, arg0: usize) -> Self
Creates a new context with the given entry point, user stack pointer, and the argument.
Sourcepub fn prepare_clone_child_return_state(&mut self)
pub fn prepare_clone_child_return_state(&mut self)
Normalizes a cloned user context so it can safely return to ring 3.
Sourcepub fn run(&mut self) -> ReturnReason
pub fn run(&mut self) -> ReturnReason
Enters user space.
It restores the user registers and jumps to the user entry point
(saved in rip).
This function returns when an exception or syscall occurs.
Methods from Deref<Target = TrapFrame>
Sourcepub fn set_retval(&mut self, rax: usize)
pub fn set_retval(&mut self, rax: usize)
Sets the return value register.