pub struct UserContext {
pub sp: u64,
pub tpidr: u64,
/* private fields */
}Available on crate feature
uspace only.Expand description
Context to enter user space.
Fields
sp: u64Stack Pointer (SP_EL0).
tpidr: u64Software Thread ID Register (TPIDR_EL0).
Implementations
Sourceimpl UserContext
impl UserContext
Sourcepub fn new(entry: usize, ustack_top: VirtAddr, arg0: usize) -> Self
pub fn new(entry: usize, ustack_top: VirtAddr, arg0: usize) -> Self
Creates a new context with the given entry point, user stack pointer, and the argument.
Sourcepub fn run(&mut self) -> ReturnReason
pub fn run(&mut self) -> ReturnReason
Enters user space.
It restores the user registers and jumps to the user entry point
(saved in elr).
This function returns when an exception or syscall occurs.
Methods from Deref<Target = TrapFrame>
Sourcepub fn set_retval(&mut self, r0: usize)
pub fn set_retval(&mut self, r0: usize)
Sets the return value register.