UserContext

Struct UserContext 

pub struct UserContext {
    pub fs_base: u64,
    pub gs_base: u64,
    /* private fields */
}
Available on crate feature uspace only.
Context to enter user space.

Fields

fs_base: u64

FS Segment Base

gs_base: u64

GS Segment Base

Implementations

Source

impl UserContext

pub fn new(entry: usize, ustack_top: VirtAddr, arg0: usize) -> Self

Creates a new context with the given entry point, user stack pointer, and the argument.

pub const fn tls(&self) -> usize

Gets the TLS area.

pub const fn set_tls(&mut self, tls_area: usize)

Sets the TLS area.

pub fn run(&mut self) -> ReturnReason

Enters user space.

It restores the user registers and jumps to the user entry point (saved in rip).

This function returns when an exception or syscall occurs.

Methods from Deref<Target = TrapFrame>

pub fn arg0(&self) -> usize

Gets the 0th syscall argument.

pub fn set_arg0(&mut self, rdi: usize)

Sets the 0th syscall argument.

pub fn arg1(&self) -> usize

Gets the 1st syscall argument.

pub fn set_arg1(&mut self, rsi: usize)

Sets the 1st syscall argument.

pub fn arg2(&self) -> usize

Gets the 2nd syscall argument.

pub fn set_arg2(&mut self, rdx: usize)

Sets the 2nd syscall argument.

pub fn arg3(&self) -> usize

Gets the 3rd syscall argument.

pub fn set_arg3(&mut self, r10: usize)

Sets the 3rd syscall argument.

pub fn arg4(&self) -> usize

Gets the 4th syscall argument.

pub fn set_arg4(&mut self, r8: usize)

Sets the 4th syscall argument.

pub fn arg5(&self) -> usize

Gets the 5th syscall argument.

pub fn set_arg5(&mut self, r9: usize)

Sets the 5th syscall argument.

pub fn ip(&self) -> usize

Gets the instruction pointer.

pub fn set_ip(&mut self, rip: usize)

Sets the instruction pointer.

pub fn sp(&self) -> usize

Gets the stack pointer.

pub fn set_sp(&mut self, rsp: usize)

Sets the stack pointer.

pub fn sysno(&self) -> usize

Gets the syscall number.

pub fn set_sysno(&mut self, rax: usize)

Sets the syscall number.

pub fn retval(&self) -> usize

Gets the return value register.

pub fn set_retval(&mut self, rax: usize)

Sets the return value register.

pub fn backtrace(&self) -> Backtrace

Unwind the stack and get the backtrace.